UpdateInfo class

Describes the result of a Shorebird update check.

Returned by the update manager after querying Shorebird for an available patch. Use isAvailable to decide whether to prompt the user to update.

Constructors

UpdateInfo({required bool isAvailable, int? currentPatchNumber, int? nextPatchNumber})
Creates an UpdateInfo describing the current update state.
const

Properties

currentPatchNumber int?
The patch number currently running in the app, or null if none.
final
hashCode int
The hash code for this object.
no setterinherited
isAvailable bool
Whether a new patch is available to download.
final
nextPatchNumber int?
The patch number that will be applied on the next restart, or null.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited