UpdateStatus enum

The lifecycle states of the updater as it checks for and applies a patch.

Inheritance
Available extensions

Values

idle → const UpdateStatus

No update activity is in progress.

checking → const UpdateStatus

Currently checking Shorebird for an available patch.

available → const UpdateStatus

A patch is available to download.

downloading → const UpdateStatus

A patch is currently being downloaded.

downloaded → const UpdateStatus

A patch has been downloaded and is staged for the next restart.

upToDate → const UpdateStatus

The app is already running the latest version.

failed → const UpdateStatus

The last update operation failed.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UpdateStatus>
A constant List of the values in this enum, in order of their declaration.