NetworkService class

Thin wrapper around connectivity_plus used to check for network access before attempting an update.

Properties

hashCode int
The hash code for this object.
no setterinherited
onConnectivityChanged Stream<List<ConnectivityResult>>
Listen to connectivity changes
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasInternet() Future<bool>
Returns true if device has internet/network connection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NetworkService
The shared singleton instance.
final